"use client";

import Image from "next/image";

import { motion } from "framer-motion";
import { useTranslations } from "next-intl";

import { ContentLines } from "@/components/shared/content-lines";
import BlurFade from "@/components/ui/blur-fade";
import { Locale } from "@/i18n/routing";

const data = [
	{
		id: 1,
		icon: "/icons/setting.png",

		title: {
			en: "High quality products",
			ar: "منتجات عالية الجودة",
		},
		description: {
			en: "We offer high quality products that are made with the best materials and the latest technology.",
			ar: "نقدم في بن طالب منتجات عالمية ومعتمدة تلبي أعلى معايير الجودة، مما يضمن لك أداءً ممتازًا وطول عمر لجميع مستلزمات المسابح.",
		},
	},
	{
		id: 2,
		icon: "/icons/wave.png",
		title: {
			en: "Innovative Solutions",
			ar: "حلول مبتكرة",
		},
		description: {
			en: "Our innovative solutions are designed to meet the unique needs of our clients.",
			ar: "حلولنا المبتكرة مصممة لتلبية الاحتياجات الفريدة لعملائنا.",
		},
	},
	{
		id: 3,
		icon: "/icons/setting-2.png",
		title: {
			en: "24/7 Support",
			ar: "دعم على مدار الساعة",
		},
		description: {
			en: "We provide 24/7 support to ensure your satisfaction and peace of mind.",
			ar: "نقدم دعمًا على مدار الساعة لضمان رضاك وراحة بالك.",
		},
	},
	{
		id: 4,
		icon: "/icons/setting-3.png",
		title: {
			en: "Sustainability",
			ar: "الاستدامة",
		},
		description: {
			en: "Our products are designed with sustainability in mind.",
			ar: "منتجاتنا مصممة مع مراعاة الاستدامة.",
		},
	},
	{
		id: 5,
		icon: "/icons/setting-4.png",
		title: {
			en: "Customization",
			ar: "التخصيص",
		},
		description: {
			en: "We offer customization options to fit your specific needs.",
			ar: "نقدم خيارات تخصيص لتناسب احتياجاتك الخاصة.",
		},
	},
	{
		id: 6,
		icon: "/icons/package.png",
		title: {
			en: "Efficiency",
			ar: "الكفاءة",
		},
		description: {
			en: "Our processes are optimized for maximum efficiency.",
			ar: "عملياتنا محسّنة لتحقيق أقصى قدر من الكفاءة.",
		},
	},
];

const Card = ({
	title,
	description,
	icon,
	index,
}: {
	title: string;
	description: string;
	icon: string;
	index: number;
}) => {
	return (
		<BlurFade
			key={index}
			duration={1.5}
			delay={index * 0.3}
			inView
			direction={"up"}
		>
			<motion.div
				className="flex h-full flex-col bg-[#f6f7fb]"
				whileHover={{
					scale: 1.05,
					boxShadow: "0px 10px 20px rgba(0, 0, 0, 0.1)",
				}}
				transition={{ type: "spring", stiffness: 300 }}
			>
				<div className="relative h-[205px]">
					<Image
						src="/arrival-product-1.png"
						alt="about-1"
						fill
						style={{ objectFit: "cover" }}
					/>
				</div>
				<div className="flex flex-grow flex-col p-6">
					<div className="flex items-center justify-between">
						<p className="text-2xl text-custom-primary-accent">{title}</p>
						<div className="flex h-[64px] w-[64px] items-center justify-center bg-custom-primary-accent">
							<Image
								src={icon}
								alt="about-1"
								width={24}
								height={24}
								style={{ width: "24px", height: "24px" }}
							/>
						</div>
					</div>
					<p className="mt-4 flex-grow text-justify text-base leading-[30px] text-[#606676]">
						{description}
					</p>
				</div>
			</motion.div>
		</BlurFade>
	);
};

function FeaturedFeatures({ locale }: { locale: Locale }) {
	const t = useTranslations("Services");

	return (
		<section className="my-12 flex flex-col items-center">
			<ContentLines
				title={t("ServiceFeatures")}
				underlineColor="custom-primary-accent"
				textColor="text-custom-primary-accent"
			/>
			<p className="text-nowrap text-3xl leading-7 text-[#202020] md:text-4xl md:leading-10">
				{t("FeaturedFeatures")}
			</p>
			<div className="mt-12 grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
				{data?.map((feature, index) => (
					<Card
						key={feature.id}
						index={index}
						title={feature.title?.[locale]}
						description={feature.description?.[locale]}
						icon={feature.icon}
					/>
				))}
			</div>
		</section>
	);
}

export default FeaturedFeatures;
